.oe-icons-wrap {
	margin-top: 5px;
	margin-bottom: 5px;
}
.oe-icons-wrap p {
	min-height: 2.2em;
	margin-bottom: 0;
}
.oe-icons-wrap p a,
.oe-icons-wrap p label {
	display: inline-block;
	vertical-align: middle;
	line-height: 2.2em;
}
.oe-icons-wrap a {
	cursor: pointer;
	text-decoration: none;
}
.oe-icons-wrap .submitdelete {
	float: none;
	display: inline-block;
	margin: 0;
	padding: 0;
	line-height: 2.2em;
	height: 100%;
}
.oe-icons-wrap .hidden {
	display: none;
}
.oe-icons-wrap ._icon {
	color: #666;
	font-size: 1.9em;
	width: auto;
	height: auto;
	vertical-align: middle;
	margin: -.1em .2em 0 .2em;
}
.oe-icons-wrap img._icon {
	max-width: 24px;
	width: 1em;
    height: 1em;
}

.oe-icons-wrap a._select:focus ._icon,
.oe-icons-wrap a._select:hover ._icon {
	color: #101010;
}

.oe-preview.menu-item {
	font-size: 1.2em;
	min-height: 0;
}
.oe-preview.menu-item a {
	text-decoration: none;
	-webkit-box-shadow: none;
    box-shadow: none;
}
.oe-preview.menu-item a > * {
	display: inline-block;
	vertical-align: middle;
	line-height: 100%;
	height: 100%;
}
.oe-preview.menu-item ._icon._before {
	margin-right: 4px;
}
.oe-preview.menu-item ._icon._after {
	margin-left: 4px;
}
.oe-preview.menu-item span.icon-wrap {
	text-align: center;
}
.oe-preview.menu-item span.icon-wrap ._icon._below {
	display: block;
    margin: 0 0 8px;
    width: auto;
    height: auto;
}
.oe-preview.menu-item span.icon-wrap img._icon._below {
    margin: 0 auto 8px auto;
}
.oe-preview.menu-item span.icon-wrap span.menu-text {
	display: block;
    line-height: 1;
}
.media-sidebar .oe-settings .setting input[type="number"],
.oe-icons-settings input[type="number"] {
	width: auto;
	max-width: 5em;
	float: none;
}
.media-sidebar .oe-settings .setting input,
.media-sidebar .oe-settings span.description {
	float: none;
}
.media-sidebar .oe-settings .setting select {
	min-width: 100px;
}

/** Settings Meta Box **/
.oe-icons-settings ._field {
	padding: .5em 0;
}
.oe-icons-settings ._field ._main {
	display: block;
	font-weight: bold;
	margin-bottom: .25em;
}
#menu-settings-column .oe-icons-settings .inside {
	margin-top: 0;
}
.oe-icons-settings .taxonomydiv .tabs-panel {
	max-height: none;
	padding-top: .3em;
	padding-bottom: .4em;
	margin-bottom: .75em;
}
.js .oe-icons-settings .taxonomydiv .tabs-panel {
	margin-bottom: 0;
}
.oe-icons-settings h4 {
	margin: 0;
}
.oe-icons-settings select {
	min-width: 110px;
}
.oe-icons-settings ._menu span.description {
	margin-left: .5em;
}
.oe-icons-settings .spinner {
	float: none;
	margin: 0 5px 0 0;
	vertical-align: middle;
}
.attachment .svg-icon img {
	max-width: 100%;
}

/* RTL */
.rtl .oe-preview.menu-item ._icon._before {
	margin-left: 4px;
	margin-right: 0;
}
.rtl .oe-preview.menu-item ._icon._after {
	margin-right: 4px;
	margin-left: 0;
}
.rtl .oe-icons-settings ._menu span.description {
	margin-right: .5em;
	margin-left: 0;
}